.. _astronomy-schema:

Astronomy
=========

The ASDF specification contains a few astronomy-specific tags that
are optional but maintained as part of the specification (for historical
reasons). These include:

.. asdf-autoschemas::

   fits/fits-1.1.0
   table/column-1.1.0
   table/table-1.1.0
   time/time-1.2.0
   unit/unit-1.0.0
   unit/defunit-1.0.0
   unit/quantity-1.2.0
